/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is FirefoxView Mozilla Extension.
 * The Initial Developer of the Original Code is Alex Sirota <alex@elbrus.com>. 
 * Portions created by Alex Sirota are Copyright (C) 2004 Alex Sirota. All Rights Reserved.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

function firefoxViewGetOpenPageText() {
	var strbundle = document.getElementById("firefoxview-strings");
	var str = strbundle.getString("viewPage");
	return str;
}

function firefoxViewGetOpenLinkText() {
	var strbundle = document.getElementById("firefoxview-strings");
	var str = strbundle.getString("viewLink");
	return str;
}

function firefoxViewGetHome() {
	var directoryService = Components.classes['@mozilla.org/file/directory_service;1']
						.getService(Components.interfaces.nsIProperties);
	var homeDir = directoryService.get('ProfD',
                   	Components.interfaces.nsILocalFile);
                   	
	homeDir.append("extensions");
	homeDir.append("{5D558C43-550F-4b12-84AB-0D8ABDA9F975}");

	return homeDir;
}

function firefoxViewGetIEMenuProgram() {
	var prog = firefoxViewGetHome();
	prog.append("IEMenu.exe");
	return prog;	
}

function firefoxViewInstall() {
	var homeDir = firefoxViewGetHome();
	var pageURL = 'file://' + homeDir.path + '\\' + 'firefoxviewpage.html';
	var linkURL = 'file://' + homeDir.path + '\\' + 'firefoxviewlink.html';

	var ieMenuProgram = firefoxViewGetIEMenuProgram();
	var ieMenuProgramProcess = Components.classes["@mozilla.org/process/util;1"]
             		.getService(Components.interfaces.nsIProcess);
	ieMenuProgramProcess.init(ieMenuProgram);
	
	ieMenuProgramProcess.run(true, ['-c', firefoxViewGetOpenPageText(), pageURL, '1'], 4);
	ieMenuProgramProcess.run(true, ['-c', firefoxViewGetOpenLinkText(), linkURL, '34'], 4);

	firefoxviewSetInstalled(true);
}

function firefoxViewUnInstall() {
	var ieMenuProgram = firefoxViewGetIEMenuProgram();
	var ieMenuProgramProcess = Components.classes["@mozilla.org/process/util;1"]
             		.getService(Components.interfaces.nsIProcess);
	ieMenuProgramProcess.init(ieMenuProgram);
	
	ieMenuProgramProcess.run(true, ['-d', firefoxViewGetOpenPageText()], 2);
	ieMenuProgramProcess.run(true, ['-d', firefoxViewGetOpenLinkText()], 2);

	firefoxviewSetInstalled(false);
}

// return true/false or null if nothing is set (first run)
function firefoxviewIsInstalled() {
   var bInstalled = null;
   try {
     bInstalled = gFirefoxViewPref.getBoolPref("is_installed");
   } 
   catch (err) {
   }

   return bInstalled;
}


function firefoxviewSetInstalled(bInstalled) {
   try {
     gFirefoxViewPref.setBoolPref("is_installed", bInstalled);
   } 
   catch (err) {
     dump("\nSetting preference for is_installed failed: " + err + "\n");
     return;
   }
   try {
	gFirefoxViewPrefService.savePrefFile(null);
   }
   catch (err) {
        dump("\nSaving preferences failed: " + err + "\n");
   }
}

// delete the is_installed user pref completely
function firefoxviewClearInstalled() {
   try {
	gFirefoxViewPref.clearUserPref("is_installed");
   } 
   catch (err) {
	dump("\nCouldn't clear user pref is_installed\n");		
   }
   try {
	gFirefoxViewPrefService.savePrefFile(null);
   }
   catch (err) {
        dump("\nSaving preferences failed: " + err + "\n");
   }
}


function firefoxviewInstallUninstallWithConfirmation(bInstall) {
   var strbundle = document.getElementById("firefoxview-strings");
   var promptOK;
   var promptProblem;

   if (bInstall) {
	   promptOK = strbundle.getString("installOKPrompt");
	   promptProblem = strbundle.getString("installProblemPrompt");
   } else {
	   promptOK = strbundle.getString("uninstallOKPrompt");
	   promptProblem = strbundle.getString("uninstallProblemPrompt");
   }

   try {
	if (bInstall) {
		firefoxViewInstall();
	} else {
		firefoxViewUnInstall();
	}
   } catch (err) {
	alert(promptProblem);
	return;
   }
   alert(promptOK);
}

var gFirefoxViewPrefService = Components.classes["@mozilla.org/preferences-service;1"]
                            .getService(Components.interfaces.nsIPrefService);
var gFirefoxViewPref = gFirefoxViewPrefService.getBranch("firefoxview."); 
